Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(158)

Unified Diff: components/certificate_reporting/error_reporter_unittest.cc

Issue 2026213002: Refactor CertificateReportSender (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/certificate_reporting/error_reporter_unittest.cc
diff --git a/components/certificate_reporting/error_reporter_unittest.cc b/components/certificate_reporting/error_reporter_unittest.cc
index cb3d2e0b0078942cd58a2e2ecaa7bbdb2db1f488..5de9737c07a7f6e5b5f325731eb0c438bca4a032 100644
--- a/components/certificate_reporting/error_reporter_unittest.cc
+++ b/components/certificate_reporting/error_reporter_unittest.cc
@@ -16,7 +16,7 @@
#include "base/memory/ptr_util.h"
#include "components/certificate_reporting/encrypted_cert_logger.pb.h"
#include "crypto/curve25519.h"
-#include "net/url_request/certificate_report_sender.h"
+#include "net/url_request/report_sender.h"
#include "testing/gtest/include/gtest/gtest.h"
namespace certificate_reporting {
@@ -28,12 +28,12 @@ const char kDummyHttpsReportUri[] = "https://example.test";
const char kDummyReport[] = "a dummy report";
const uint32_t kServerPublicKeyTestVersion = 16;
// A mock CertificateReportSender that keeps track of the last report
// sent.
-class MockCertificateReportSender : public net::CertificateReportSender {
+class MockCertificateReportSender : public net::ReportSender {
public:
MockCertificateReportSender()
- : net::CertificateReportSender(nullptr, DO_NOT_SEND_COOKIES) {}
+ : net::ReportSender(nullptr, DO_NOT_SEND_COOKIES) {}
~MockCertificateReportSender() override {}
void Send(const GURL& report_uri, const std::string& report) override {
« no previous file with comments | « components/certificate_reporting/error_reporter.cc ('k') | ios/chrome/browser/browser_state/chrome_browser_state_io_data.h » ('j') | no next file with comments »
@@ -28,12 +28,12 @@ const char kDummyHttpsReportUri[] = "https://example.test";
const char kDummyReport[] = "a dummy report";
const uint32_t kServerPublicKeyTestVersion = 16;
-// A mock CertificateReportSender that keeps track of the last report
+// A mock ReportSender that keeps track of the last report
// sent.

Powered by Google App Engine
This is Rietveld 408576698